Coverage for api/tests/test_templates.py: 0%

# Coverage for api/tests/test_templates.py : 0%

## 5 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 class TestApiTemplates:

2 """

3 Test templates functionalities

4 """

5

6 def test_yo_render(self, test_client):

7 response = test_client.get("/render_demo")

8

9 assert response.status_code == 200

10 assert b"Fruit mango" in response.data